@@ -530,7 +530,7 @@ def split_df_input_and_target(df, columns):
         or y is a pandas DataFrame if columns is a list of strings.
     """
     if type(columns) == str:
-        df.drop(columns=[columns]), df[columns]
+        return df.drop(columns=[columns]), df[columns]
     return df.drop(columns=columns), df[columns]
 
 
