@@ -2,6 +2,7 @@
 import configparser
 import datetime
 from email.mime.text import MIMEText
+import inspect
 import json
 import logging
 import os
@@ -337,7 +338,9 @@ def prepare_slurm_job(dryrun, force, verbose, restore, mail, plan):
     if not os.path.isdir('slurmjobs'):
         os.makedirs('slurmjobs')
     timestamp = datetime.datetime.now().strftime('%Y_%m_%d__%H_%M_%S')
-    jobfile = os.path.join('slurmjobs', f'{timestamp}_{jobname}.job')
+    plan_noext = os.path.splitext(os.path.basename(plan))[0]
+    job_filename = f'{timestamp}_{jobname}_{plan_noext}.job'
+    jobfile = os.path.join('slurmjobs', job_filename)
     with open(jobfile, 'w') as o_f:
         o_f.write(content)
     return jobfile
@@ -366,3 +369,33 @@ def get_job_id():
 
     # fallback job id
     return os.getpid()
+
+
+def check_serializability(content):
+    """
+    Returns a copy of a dict object that can be json-serialized.
+
+    For each item pair of the dictionary, if key and value are json
+    serializable, the pair is kept as-is. Otherwise, the value of the pair is
+    returned as string to enable storing in the database.
+
+    Args:
+        content: anything
+            The object to be checked
+    Returns:
+        A copy of the results which can be stored in a JSON column in the db,
+        or as a pickle for the pickle storage handler
+    """
+    try:
+        _ = json.dumps(content)
+        return content
+    except TypeError:
+        if type(content) == list or type(content) == tuple:
+            cleaned = [check_serializability(x) for x in content]
+        elif type(content) == dict:
+            cleaned = {k: check_serializability(v) for k, v in content.items()}
+        elif callable(content):
+            cleaned = inspect.getsource(content).strip()
+        else:
+            cleaned = str(content)
+        return cleaned
